import os
import redis


RC_DB_TYPE = os.getenv("RC_DB_TYPE", "strict")

if RC_DB_TYPE == "strict":
    READ_HOST = os.getenv("READ_HOST", "localhost")
    READ_PORT = int(os.getenv("READ_PORT", "6379"))
    READ_DB = int(os.getenv("READ_DB", "0"))
    WRITE_HOST = os.getenv("WRITE_HOST", "localhost")
    WRITE_PORT = int(os.getenv("WRITE_PORT", "6379"))
    WRITE_DB = int(os.getenv("WRITE_DB", "0"))
    r = redis.StrictRedis(host='localhost', port=6379, db=0)
    w = redis.StrictRedis(host='localhost', port=6379, db=0)
elif RC_DB_TYPE == "url":
    REDIS_READ_URL = os.getenv("REDIS_READ_URL", "redis://localhost")
    REDIS_WRITE_URL = os.getenv("REDIS_WRITE_URL", "redis://localhost")
    r = redis.from_url(REDIS_READ_URL)
    w = redis.from_url(REDIS_WRITE_URL)
else:
    raise



from setuptools import setup


setup(
    name="simple_redis_conn",
    version="0.0.2",
    packages=[
        "simple_redis_conn"
    ],
    author="Tyler Agee",
    author_email="tyler@pyroturtle.com",
    url="https://github.com/tekton/simple_redis_conn_python",
    license="MIT License",
    description="Mapping operators to a dictionary switch",
    long_description="Check the file README.md",
    keywords="operator",
    install_requires=['redis', 'hiredis'],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    package_data={"simple_redis_conn": ["README.md"]}
)
